<?php
/** @license MIT
 * Copyright 2018 J. King et al.
 * See LICENSE and AUTHORS files for details */

declare(strict_types=1);
namespace MensBeam\Intl\Encoding;

class ISO88593 extends SingleByteEncoding {
    const NAME = "ISO-8859-3";
    const LABELS = [
        "csisolatin3",
        "iso-8859-3",
        "iso-ir-109",
        "iso8859-3",
        "iso88593",
        "iso_8859-3",
        "iso_8859-3:1988",
        "l3",
        "latin3",
    ];

    const TABLE_DEC_CHAR = ["\u{80}","\u{81}","\u{82}","\u{83}","\u{84}","\u{85}","\u{86}","\u{87}","\u{88}","\u{89}","\u{8a}","\u{8b}","\u{8c}","\u{8d}","\u{8e}","\u{8f}","\u{90}","\u{91}","\u{92}","\u{93}","\u{94}","\u{95}","\u{96}","\u{97}","\u{98}","\u{99}","\u{9a}","\u{9b}","\u{9c}","\u{9d}","\u{9e}","\u{9f}","\u{a0}","\u{126}","\u{2d8}","\u{a3}","\u{a4}",38=>"\u{124}","\u{a7}","\u{a8}","\u{130}","\u{15e}","\u{11e}","\u{134}","\u{ad}",47=>"\u{17b}","\u{b0}","\u{127}","\u{b2}","\u{b3}","\u{b4}","\u{b5}","\u{125}","\u{b7}","\u{b8}","\u{131}","\u{15f}","\u{11f}","\u{135}","\u{bd}",63=>"\u{17c}","\u{c0}","\u{c1}","\u{c2}",68=>"\u{c4}","\u{10a}","\u{108}","\u{c7}","\u{c8}","\u{c9}","\u{ca}","\u{cb}","\u{cc}","\u{cd}","\u{ce}","\u{cf}",81=>"\u{d1}","\u{d2}","\u{d3}","\u{d4}","\u{120}","\u{d6}","\u{d7}","\u{11c}","\u{d9}","\u{da}","\u{db}","\u{dc}","\u{16c}","\u{15c}","\u{df}","\u{e0}","\u{e1}","\u{e2}",100=>"\u{e4}","\u{10b}","\u{109}","\u{e7}","\u{e8}","\u{e9}","\u{ea}","\u{eb}","\u{ec}","\u{ed}","\u{ee}","\u{ef}",113=>"\u{f1}","\u{f2}","\u{f3}","\u{f4}","\u{121}","\u{f6}","\u{f7}","\u{11d}","\u{f9}","\u{fa}","\u{fb}","\u{fc}","\u{16d}","\u{15d}","\u{2d9}"];
    const TABLE_DEC_CODE = [128,129,130,131,132,133,134,135,136,137,138,139,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,157,158,159,160,294,728,163,164,38=>292,167,168,304,350,286,308,173,47=>379,176,295,178,179,180,181,293,183,184,305,351,287,309,189,63=>380,192,193,194,68=>196,266,264,199,200,201,202,203,204,205,206,207,81=>209,210,211,212,288,214,215,284,217,218,219,220,364,348,223,224,225,226,100=>228,267,265,231,232,233,234,235,236,237,238,239,113=>241,242,243,244,289,246,247,285,249,250,251,252,365,349,729];
    const TABLE_ENC      = [128=>"\x80","\x81","\x82","\x83","\x84","\x85","\x86","\x87","\x88","\x89","\x8A","\x8B","\x8C","\x8D","\x8E","\x8F","\x90","\x91","\x92","\x93","\x94","\x95","\x96","\x97","\x98","\x99","\x9A","\x9B","\x9C","\x9D","\x9E","\x9F","\xA0",163=>"\xA3","\xA4",167=>"\xA7","\xA8",173=>"\xAD",176=>"\xB0",178=>"\xB2","\xB3","\xB4","\xB5",183=>"\xB7","\xB8",189=>"\xBD",192=>"\xC0","\xC1","\xC2",196=>"\xC4",199=>"\xC7","\xC8","\xC9","\xCA","\xCB","\xCC","\xCD","\xCE","\xCF",209=>"\xD1","\xD2","\xD3","\xD4",214=>"\xD6","\xD7",217=>"\xD9","\xDA","\xDB","\xDC",223=>"\xDF","\xE0","\xE1","\xE2",228=>"\xE4",231=>"\xE7","\xE8","\xE9","\xEA","\xEB","\xEC","\xED","\xEE","\xEF",241=>"\xF1","\xF2","\xF3","\xF4",246=>"\xF6","\xF7",249=>"\xF9","\xFA","\xFB","\xFC",264=>"\xC6","\xE6","\xC5","\xE5",284=>"\xD8","\xF8","\xAB","\xBB","\xD5","\xF5",292=>"\xA6","\xB6","\xA1","\xB1",304=>"\xA9","\xB9",308=>"\xAC","\xBC",348=>"\xDE","\xFE","\xAA","\xBA",364=>"\xDD","\xFD",379=>"\xAF","\xBF",728=>"\xA2","\xFF"];
}
